pub enum GitBranchNameError {
Empty,
InvalidName,
MissingRemoteOrBranch,
}Expand description
Error returned while parsing branch names.
Variants
Empty
The supplied branch name was empty.
InvalidName
The supplied branch name used syntax this crate rejects.
MissingRemoteOrBranch
A remote-tracking name did not include both remote and branch parts.