pub struct ShortGitOid(/* private fields */);Expand description
A short object identifier prefix.
Implementations
Sourceimpl ShortGitOid
impl ShortGitOid
Sourcepub fn new(value: impl AsRef<str>) -> Result<ShortGitOid, GitOidParseError>
pub fn new(value: impl AsRef<str>) -> Result<ShortGitOid, GitOidParseError>
Creates a short object identifier prefix from hexadecimal text.
Errors
Returns GitOidParseError when the text is empty, too short, too long,
or contains non-hexadecimal characters.
Sourcepub const fn kind_hint(&self) -> Option<GitOidKind>
pub const fn kind_hint(&self) -> Option<GitOidKind>
Returns the best known object identifier kind from the prefix length.